"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsumersDefaults = exports.ConsumersBooter = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/no-unused-vars */
const boot_1 = require("@loopback/boot");
const core_1 = require("@loopback/core");
const debug_1 = tslib_1.__importDefault(require("debug"));
const types_1 = require("../types");
const debug = debug_1.default('loopback:queue-consumer:booter');
let ConsumersBooter = class ConsumersBooter extends boot_1.BaseArtifactBooter {
    constructor(app, projectRoot, consumerConfig = {}) {
        super(projectRoot, 
        // Set Consumer Booter Options if passed in via bootConfig
        Object.assign({}, exports.ConsumersDefaults, consumerConfig));
        this.app = app;
        this.consumerConfig = consumerConfig;
        debug('consumerConfig: ', consumerConfig);
    }
    /**
     * Uses super method to get a list of Artifact classes.
     */
    async load() {
        await super.load();
        this.classes.forEach(cls => {
            this.consumers(cls);
        });
    }
    /**
     * Register a Consumer class with this application.
     *
     * @param consumerCtor - The consumer class
     * (constructor function).
     * @param name - Optional controller name, default to the class name
     * @returns The newly created binding, you can use the reference to
     * further modify the binding, e.g. lock the value to prevent further
     * modifications.
     *
     */
    consumers(consumerCtor, nameOrOptions) {
        debug('Adding consumer %s', nameOrOptions !== null && nameOrOptions !== void 0 ? nameOrOptions : consumerCtor.name);
        const binding = core_1.createBindingFromClass(consumerCtor).apply(types_1.asQueueConsumer);
        this.app.add(binding);
        return binding;
    }
};
ConsumersBooter = tslib_1.__decorate([
    boot_1.booter('consumers'),
    tslib_1.__param(0, core_1.inject(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, core_1.inject(boot_1.BootBindings.PROJECT_ROOT)),
    tslib_1.__param(2, core_1.config()),
    tslib_1.__metadata("design:paramtypes", [core_1.Application, String, Object])
], ConsumersBooter);
exports.ConsumersBooter = ConsumersBooter;
/**
 * Normalize name or options to `BindingFromClassOptions`
 * @param nameOrOptions - Name or options for binding from class
 */
function toOptions(nameOrOptions) {
    if (typeof nameOrOptions === 'string') {
        return { name: nameOrOptions };
    }
    return nameOrOptions !== null && nameOrOptions !== void 0 ? nameOrOptions : {};
}
/**
 * Default ArtifactOptions for ConsumersBooter.
 */
exports.ConsumersDefaults = {
    dirs: ['consumers'],
    extensions: ['.consumer.js'],
    nested: true,
};
//# sourceMappingURL=consumers.booter.js.map