"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueObserver = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/no-explicit-any */
const core_1 = require("@loopback/core");
const __1 = require("../..");
const keys_1 = require("../keys");
let QueueObserver = class QueueObserver {
    constructor(getMetadata, rabbitmqConsumer, getConsumers) {
        this.getMetadata = getMetadata;
        this.rabbitmqConsumer = rabbitmqConsumer;
        this.getConsumers = getConsumers;
    }
    /**
     * This method will be invoked when the application starts
     */
    async start() {
        await this.initConsumers();
        this.rabbitmqConsumer.on('re-established-connection', () => {
            this.initConsumers().then(() => { }, () => { });
        });
    }
    async initConsumers() {
        const consumers = await this.getConsumers();
        const getMethods = (instance) => {
            const onlyFunctions = (property) => typeof instance[property] === 'function' && property !== 'constructor';
            const propertyNames = Object.getOwnPropertyNames(Object.getPrototypeOf(instance));
            return propertyNames.filter(onlyFunctions);
        };
        // Init all queue consumers
        for (const myConsumer of consumers) {
            for (const method of getMethods(myConsumer)) {
                const methodMetadata = core_1.MetadataInspector.getMethodMetadata(keys_1.RABBIT_CONSUME_METADATA_ACCESSOR, Object.getPrototypeOf(myConsumer), method);
                if (methodMetadata) {
                    if (methodMetadata.enabled || methodMetadata.enabled === undefined) {
                        await this.rabbitmqConsumer.setupSubscriberChannel(myConsumer[method].bind(myConsumer), methodMetadata);
                    }
                }
            }
        }
    }
    /**
     * This method will be invoked when the application stops
     */
    async stop() { }
};
QueueObserver = tslib_1.__decorate([
    core_1.extensionPoint(keys_1.QUEUE_CONSUMER, {
        tags: [{ [core_1.ContextTags.KEY]: keys_1.QueueBindings.COMPONENT.key }],
        scope: core_1.BindingScope.SINGLETON,
    }),
    core_1.lifeCycleObserver('webhook'),
    tslib_1.__param(0, core_1.inject.getter(keys_1.QueueBindings.RABBIT_CONSUME_METADATA)),
    tslib_1.__param(1, core_1.inject(__1.RabbitmqBindings.RABBITMQ_CONSUMER)),
    tslib_1.__param(2, core_1.extensions()),
    tslib_1.__metadata("design:paramtypes", [Function, __1.RabbitmqConsumer, Function])
], QueueObserver);
exports.QueueObserver = QueueObserver;
//# sourceMappingURL=queue.observer.js.map